\name{gotomax}
\alias{gotomax}
\title{Local search function}
\description{Finds local maxima of the score function 'tscore' by greedy hill climbing.}
\usage{gotomax(dat, split, p = 50, p.offs = 0, min.split.size = ceiling(0.1*ncol(dat)))}
\arguments{
  \item{dat}{The gene expression data matrix. Rows correspond to genes, and columns correspond to samples.}
  \item{split}{Either a binary vector encoding a bipartition of the set of samples, or a binary matrix with
  every row encoding a bipartition of the set of samples.}
  \item{p}{The number of best discriminating genes selected for computing the score of a bipartition.}
  \item{p.offs}{The number of very best discriminating genes that are ignored when computing the score of 
a partition. Thus only the genes with ranks p.offs+1, ..., p are used to compute the score.}
  \item{min.split.size}{The minimal size either class of a bipartition must have to be accepted as a local
  maximum.}
}

\value{
  A binary matrix where each column (except the last one) represents a sample (in the original 
order). The rows encode the found local maximum bipartitions. The last entry in each row gives the score of the partition.}

\examples{
data(alizadeh)
split <- rep(0, ncol(alizadeh$x))
split[which(alizadeh$type=="FL")] <- 1
y <- gotomax(alizadeh$x, split) 
}
\keyword{cluster}
