\name{isis}
\alias{isis}
\title{Class discovery for microarray data}
\description{Finds bipartitions of a set of tissue samples that show clear 
separation regarding the expression of a subset of genes.}
\usage{isis(x, p = 50, p.offs = 0, max.nr.cand.splits = 500)}
\arguments{
  \item{x}{The gene expression data matrix. Rows correspond to genes, and columns correspond to samples. 
  The values in x may be normalized logarithms of intensities or log-ratios.}
  \item{p}{The number of best discriminating genes selected for computing the score of a bipartition.}
  \item{p.offs}{The number of very best discriminating genes that are ignored when computing the score of 
a partition. Thus only the genes with ranks p.offs+1, ..., p are used to compute the score. A value >0 may improve the robustness of the score, sorting out possibly spurious partitions 
with very few genes that discriminate very well between the two groups.}
  \item{max.nr.cand.splits}{After the generation of candidate bipartitions, only the max.nr.cand.splits 
partitions with highest scores are further investigated. This is used in order 
to control the running time of the program.}
}

\details{
It may be useful to first discard genes from the data matrix that display consistently low variance across the samples or 
consistently low expression intensity. 
For the generation of candidate bipartitions, the data matrix is
enlarged by adding average expression profiles of all clusters of genes resulting from a centroid linkage 
hierarchical clustering based on the correlation coefficient as similarity measure.
In order to reduce computation time, similar candidate partitions are merged through hierarchical clustering
before applying the local search to find local maximum partitions (see 'gotomax').
}


\value{
A matrix where each column (except the last one) represents a sample (in the original 
order). The rows represent the found bipartitions with highest scores, coded as 0/1-vectors. 
The last entry in each row gives the score of the partition. Only 
partitions with each group containing at least 10% of the samples are considered.
}

\references{
Identifying Splits with Clear Separation: A New Class Discovery Method for 
Gene Expression Data. Anja von Heydebreck, Wolfgang Huber, Annemarie Poustka, and Martin 
Vingron, ISMB 2001, Bioinformatics 17, Suppl. 1 (2001) p. 107-114.
}

\author{Anja von Heydebreck and Wolfgang Huber \url{http://www.molgen.mpg.de/~heydebre}}

\examples{
data(alizadeh)
cputime <- system.time(
                       y <- isis(alizadeh$x)
                         )
cat("Time used:", cputime[1], "sec on CPU,", cputime[3], "sec on wallclock.\n")	
}		 
\keyword{cluster}
