\name{tscore}
\alias{tscore}
\title{Score function for bipartitions}
\description{Computes a score for a given bipartition of the set of samples that measures how well the two
classes are separated by the expression levels of a suitable subset of genes.}
\usage{tscore(dat, split, p = 50, p.offs = 0)}
\arguments{
  \item{dat}{The gene expression data matrix. Rows correspond to genes, and columns correspond to samples. 
  The values in x may be normalized logarithms of intensities or log-ratios.}
  \item{split}{Either a binary vector encoding a bipartition of the set of samples, or a binary matrix with
  every row encoding a bipartition of the set of samples.}
  \item{p}{The number of best discriminating genes selected for computing the score of a bipartition.}
  \item{p.offs}{The number of very best discriminating genes that are ignored when computing the score of 
a partition. Thus only the genes with ranks p.offs+1, ..., p are used to compute the score.}
}

\details{
First, the genes with ranks p.offs+1, ..., p according to the two-sample t-statistic are selected. Then, a
discriminant axis for a naive Bayes classifier (ML classification rule for two normal distributions with
identical, diagonal covariance matrix) based on these genes is computed, and the score is computed as the
t-statistic for the coordinates of the sample vectors projected onto this axis.
}

\value{  
A vector with the scores of the bipartitions encoded in 'split'.
}
\examples{
data(alizadeh)
split <- rep(0, ncol(alizadeh$x))
split[which(alizadeh$type=="FL")] <- 1
z <- tscore(alizadeh$x, split) 
}
\keyword{cluster}
